==> mirador-canvaslink-0.1.0.tgz: package/es/components/ShareControl.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import ShareIcon from "@material-ui/icons/Share";
import { MiradorMenuButton } from "mirador/dist/es/src/components/MiradorMenuButton";
import PropTypes from "prop-types";
import React from "react";

var ShareControl = function ShareControl(_ref) {
  var containerId = _ref.containerId,
      options = _ref.options,
      t = _ref.t,
      updateOptions = _ref.updateOptions;
  var dialogOpen = options.dialogOpen,
      enabled = options.enabled;

  if (!enabled) {
    return null;
  }

  return /*#__PURE__*/React.createElement(MiradorMenuButton, {
    "aria-expanded": dialogOpen,
    "aria-label": t("canvasLink.shareLink"),
    containerId: containerId,
    onClick: function onClick() {
      return updateOptions(_extends({}, options, {
        dialogOpen: !dialogOpen
      }));
    }
  }, /*#__PURE__*/React.createElement(ShareIcon, null));
};

ShareControl.propTypes = process.env.NODE_ENV !== "production" ? {
  containerId: PropTypes.string.isRequired,
  options: PropTypes.shape({
    dialogOpen: PropTypes.bool.isRequired,
    enabled: PropTypes.bool.isRequired
  }).isRequired,
  t: PropTypes.func.isRequired,
  updateOptions: PropTypes.func.isRequired
} : {};
export default ShareControl;

==> mirador-canvaslink-0.2.1.tgz: package/es/components/ShareControl.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import ShareIcon from "@material-ui/icons/Share";
import { MiradorMenuButton } from "mirador/dist/es/src/components/MiradorMenuButton";
import PropTypes from "prop-types";
import React from "react";

var ShareControl = function ShareControl(_ref) {
  var containerId = _ref.containerId,
      options = _ref.options,
      t = _ref.t,
      updateOptions = _ref.updateOptions,
      windowViewType = _ref.windowViewType;
  var dialogOpen = options.dialogOpen,
      enabled = options.enabled,
      singleCanvasOnly = options.singleCanvasOnly;

  if (!enabled || // Only show in single canvas view if configured
  singleCanvasOnly && windowViewType !== "single" || // Never show in gallery view
  windowViewType === "gallery") {
    return null;
  }

  return /*#__PURE__*/React.createElement(MiradorMenuButton, {
    "aria-expanded": dialogOpen,
    "aria-label": t("canvasLink.shareLink"),
    containerId: containerId,
    onClick: function onClick() {
      return updateOptions(_extends({}, options, {
        dialogOpen: !dialogOpen
      }));
    }
  }, /*#__PURE__*/React.createElement(ShareIcon, null));
};

ShareControl.propTypes = process.env.NODE_ENV !== "production" ? {
  containerId: PropTypes.string.isRequired,
  options: PropTypes.shape({
    dialogOpen: PropTypes.bool.isRequired,
    enabled: PropTypes.bool.isRequired,
    singleCanvasOnly: PropTypes.bool.isRequired
  }).isRequired,
  t: PropTypes.func.isRequired,
  updateOptions: PropTypes.func.isRequired,
  windowViewType: PropTypes.string.isRequired
} : {};
export default ShareControl;
